@@ -12,7 +12,7 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-__version__ = "0.9.3"
+__version__ = "1.0.0"
 
 from extras.plugins import PluginConfig
 
@@ -21,7 +21,7 @@ class OnboardingConfig(PluginConfig):
     """Plugin configuration for the netbox_onboarding plugin."""
 
     name = "netbox_onboarding"
-    verbose_name = "A plugin to easily onboard new devices."
+    verbose_name = "Device Onboarding"
     version = __version__
     author = "Network to Code"
     description = "A plugin for NetBox to easily onboard new devices."
